==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/kw-GB.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m."
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "kw-GB",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Lun",
    "Mth",
    "Mhr",
    "Yow",
    "Gwe",
    "Sad",
    "Sul"
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_format_wide => [
    "dy Lun",
    "dy Meurth",
    "dy Merher",
    "dy Yow",
    "dy Gwener",
    "dy Sadorn",
    "dy Sul"
  ],
  day_stand_alone_abbreviated => [
    "Lun",
    "Mth",
    "Mhr",
    "Yow",
    "Gwe",
    "Sad",
    "Sul"
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_stand_alone_wide => [
    "dy Lun",
    "dy Meurth",
    "dy Merher",
    "dy Yow",
    "dy Gwener",
    "dy Sadorn",
    "dy Sul"
  ],
  era_abbreviated => [
    "RC",
    "AD"
  ],
  era_narrow => [
    "RC",
    "AD"
  ],
  era_wide => [
    "RC",
    "AD"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Cornish",
  month_format_abbreviated => [
    "Gen",
    "Hwe",
    "Meu",
    "Ebr",
    "Me",
    "Met",
    "Gor",
    "Est",
    "Gwn",
    "Hed",
    "Du",
    "Kev"
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_format_wide => [
    "mis Genver",
    "mis Hwevrer",
    "mis Meurth",
    "mis Ebrel",
    "mis Me",
    "mis Metheven",
    "mis Gortheren",
    "mis Est",
    "mis Gwynngala",
    "mis Hedra",
    "mis Du",
    "mis Kevardhu"
  ],
  month_stand_alone_abbreviated => [
    "Gen",
    "Hwe",
    "Meu",
    "Ebr",
    "Me",
    "Met",
    "Gor",
    "Est",
    "Gwn",
    "Hed",
    "Du",
    "Kev"
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_stand_alone_wide => [
    "mis Genver",
    "mis Hwevrer",
    "mis Meurth",
    "mis Ebrel",
    "mis Me",
    "mis Metheven",
    "mis Gortheren",
    "mis Est",
    "mis Gwynngala",
    "mis Hedra",
    "mis Du",
    "mis Kevardhu"
  ],
  name => "Cornish United Kingdom",
  native_language => "kernewek",
  native_name => "kernewek Rywvaneth Unys",
  native_script => undef,
  native_territory => "Rywvaneth Unys",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  script => undef,
  territory => "United Kingdom",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/kw-GB.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "kw-GB",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Lun",
    "Mth",
    "Mhr",
    "Yow",
    "Gwe",
    "Sad",
    "Sul",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "dy Lun",
    "dy Meurth",
    "dy Merher",
    "dy Yow",
    "dy Gwener",
    "dy Sadorn",
    "dy Sul",
  ],
  day_stand_alone_abbreviated => [
    "Lun",
    "Mth",
    "Mhr",
    "Yow",
    "Gwe",
    "Sad",
    "Sul",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "dy Lun",
    "dy Meurth",
    "dy Merher",
    "dy Yow",
    "dy Gwener",
    "dy Sadorn",
    "dy Sul",
  ],
  era_abbreviated => [
    "RC",
    "AD",
  ],
  era_narrow => [
    "RC",
    "AD",
  ],
  era_wide => [
    "RC",
    "AD",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Cornish",
  month_format_abbreviated => [
    "Gen",
    "Hwe",
    "Meu",
    "Ebr",
    "Me",
    "Met",
    "Gor",
    "Est",
    "Gwn",
    "Hed",
    "Du",
    "Kev",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "mis Genver",
    "mis Hwevrer",
    "mis Meurth",
    "mis Ebrel",
    "mis Me",
    "mis Metheven",
    "mis Gortheren",
    "mis Est",
    "mis Gwynngala",
    "mis Hedra",
    "mis Du",
    "mis Kevardhu",
  ],
  month_stand_alone_abbreviated => [
    "Gen",
    "Hwe",
    "Meu",
    "Ebr",
    "Me",
    "Met",
    "Gor",
    "Est",
    "Gwn",
    "Hed",
    "Du",
    "Kev",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "mis Genver",
    "mis Hwevrer",
    "mis Meurth",
    "mis Ebrel",
    "mis Me",
    "mis Metheven",
    "mis Gortheren",
    "mis Est",
    "mis Gwynngala",
    "mis Hedra",
    "mis Du",
    "mis Kevardhu",
  ],
  name => "Cornish United Kingdom",
  native_language => "kernewek",
  native_name => "kernewek Rywvaneth Unys",
  native_script => undef,
  native_territory => "Rywvaneth Unys",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "United Kingdom",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}
